# Subdomain Takeover

Subdomain takeover attacks are a class of security issues where an attacker can seize control of an organization's
subdomain via cloud services like GitHub, AWS, or Azure. They commonly happen when the third-party service is not needed
anymore, but the subdomain DNS entries are not cleaned.

If an attacker can control one of your subdomains,
they can perform multiple types of attacks. Depending on the third-party service provider's capabilities.

- Perform cross-site scripting
- Phishing attacks
- Stealing Broadly Scoped Cookies
- Clickjacking 
